function [ H ] = conditionalEntropy( Y, X )
%CONDITIONALENTROPY how much one graph determines the other
% consider the upper triangle of the adjacency matrix as a binary string
% For us, X and Y are {0,1}, and p(x,y) is the fraction of times first 
% graph has/doesn’t have a particular edge (x = 1 or x = 0, respectively) 
% when the other graph has/doesn’t have that edge (y = 1 or y = 0).
%
% H(Y|X) = sum_{x in X,y in Y} p(x,y) * log(p(x)/p(x,y))
    %
    % this version eats too much memory....
    mask = triu(true(size(Y)),1); %that's the upper triangular of the original graph
    vX = X(mask);     
    vY = Y(mask);               
    binary = logical([0,1]);
    H = 0;            
    for x=binary
     for y=binary
         pxy = sum(vX==x & vY==y)/length(vX);
         px = sum(vX == x)/length(vX);
         H = H + logMult(pxy, px / pxy);
     end
    end
    % memory-optimized version 
%     n = length(X);
%     pxy00 = 0;
%     pxy01 = 0;
%     pxy10 = 0;
%     pxy11 = 0;
%     px0 = 0;
%     px1 = 0;
%     k = 0;
%     for i = 1:n
%         for j = (i+1):n
%             k = k+1;
%             x0 = X(i,j) == 0;
%             x1 = ~x0;
%             y0 = Y(i,j) == 0;
%             y1 = ~y0;
% 
%             pxy00 = pxy00 + (x0 & y0);
%             pxy01 = pxy01 + (x0 & y1);
%             pxy10 = pxy10 + (x1 & y0);
%             pxy11 = pxy11 + (x1 & y1);
%             
%             px0 = px0 + x0;
%             px1 = px1 + x1;
%         end
%     end
%     pxy00 = pxy00/k;
%     pxy01 = pxy01/k;
%     pxy10 = pxy10/k;
%     pxy11 = pxy11/k;
%     px0 = px0/k;
%     px1 = px1/k;
%     H =   logMult(pxy00, px0 / pxy00) ...
%         + logMult(pxy01, px0 / pxy01)...
%         + logMult(pxy10, px1 / pxy10)...
%         + logMult(pxy11, px1 / pxy11);
end

