distFiles = dir('Data/paramDist_gammaH_*');
evalCrit = 'NLogL';
[distrRes,~]=allfitdist([0.1,0.5,0.1]);
distNames = cell(1,length(distrRes));
for i = 1:length(distrRes)
    distNames{i} = distrRes(i).DistName;
end
resTableGamma = nan(length(distNames), length(distFiles));
resTableH = nan(length(distNames), length(distFiles));
resTableSize = nan(length(distNames), length(distFiles));
dataSetNames = cell(1, length(distFiles));
for i=1:length(distFiles) 
    dataSetNames{i} = distFiles(i).name(18:(end-4));
    f = [distFiles(i).folder '/' distFiles(i).name]; 
    dataArray = textscan(fopen(f,'r'), '%f%f%f%[^\n\r]', 'Delimiter', ',',  'ReturnOnError', false);
    coreSize = dataArray{:,2};
    relCoreSize = dataArray{:,2}./dataArray{:,3};
    relCoreSizeAsInteger = round(relCoreSize * 1000);
    relTailSize = dataArray{:,1}./dataArray{:,2};
    relTailSizeAsInteger = round(relTailSize * 1000)+1;

    [qGammaDist, gammaDist] = allfitdist(relCoreSizeAsInteger(relCoreSizeAsInteger>0),evalCrit);
    [qHDist, HDist] = allfitdist(relTailSizeAsInteger,evalCrit);
    [qSizeDist, sizeDist] = allfitdist(dataArray{:,3},evalCrit);

    for j = 1:length(qGammaDist)
        resTableGamma(strcmp(qGammaDist(j).DistName, distNames),i) = qGammaDist(j).(evalCrit);
    end
    for j = 1:length(qHDist)
        resTableH(strcmp(qHDist(j).DistName, distNames),i) = qHDist(j).(evalCrit);
    end
    for j = 1:length(qSizeDist)
        resTableSize(strcmp(qSizeDist(j).DistName, distNames),i) = qSizeDist(j).(evalCrit);
    end
end
%%
tGamma = array2table(resTableGamma,'RowNames',distNames,'VariableNames',dataSetNames);
tGamma({'generalized pareto','beta'},:)=[];
atGamma = table2array(tGamma);
mask = ones(15,4).*[1:4];
relativeToNormalDist = atGamma-atGamma(12,:);
figure;
bh=boxplot(reshape(relativeToNormalDist,[1,15*4]),reshape(mask,[1,15*4]),'Colors', [0 0 0]);
set(gca,'xticklabel',{'Amazon', 'DBLP', 'Friendster', 'YouTube'});
lines = findobj(gcf, 'type', 'line', 'Tag', 'Median');
set(lines, 'Color', 'r');
ylabel('LL relative to LL of Normal dist');
set(bh(:), 'LineWidth', 2);
set(gca,'FontSize',18) 
set(gca,'FontName','Times New Roman');
set(gca,'LineWidth',1.5)
fig=gcf;
fig.PaperUnits = 'inches';
fig.PaperPosition = [0 0 5.5 4];
fig.PaperOrientation = 'landscape';
path = 'Results/distfitGamma.pdf';
print(path, '-dpdf', '-r0');
system(strjoin({'pdfcrop' path path}, ' '));

tH = array2table(abs(resTableH),'RowNames',distNames,'VariableNames',dataSetNames);
tH({'generalized pareto','beta'},:)=[];
atH = table2array(tH);
mask = ones(15,4).*[1:4];
relativeToExponentialDist = atH-atH(4,:);
figure;
bh=boxplot(reshape(relativeToExponentialDist,[1,15*4]),reshape(mask,[1,15*4]),'Colors', [0 0 0]);
set(gca,'xticklabel',{'Amazon', 'DBLP', 'Friendster', 'YouTube'});
lines = findobj(gcf, 'type', 'line', 'Tag', 'Median');
set(lines, 'Color', 'r');
ylabel('LL relative to LL of Exp. dist');
set(bh(:), 'LineWidth', 2);
set(gca,'FontSize',18) 
set(gca,'FontName','Times New Roman');
set(gca,'LineWidth',1.5)
fig=gcf;
fig.PaperUnits = 'inches';
fig.PaperPosition = [0 0 5.5 4];
fig.PaperOrientation = 'landscape';
path = 'Results/distfitH.pdf';
print(path, '-dpdf', '-r0');
system(strjoin({'pdfcrop' path path}, ' '));

tSize = array2table(resTableSize,'RowNames',distNames,'VariableNames',dataSetNames);
tSize({'generalized pareto','beta'},:)=[];
atSize = table2array(tSize);
mask = ones(15,4).*[1:4];
relativeToGenExtValDist = atSize-atSize(1,:);
figure;
bh=boxplot(reshape(relativeToGenExtValDist,[1,15*4]),reshape(mask,[1,15*4]),'Colors', [0 0 0]);
set(gca,'xticklabel',{'Amazon', 'DBLP', 'Friendster', 'YouTube'});
lines = findobj(gcf, 'type', 'line', 'Tag', 'Median');
set(lines, 'Color', 'r');
ylabel('LL relative to LL of GEV dist');
set(bh(:), 'LineWidth', 2);
set(gca,'FontSize',18) 
set(gca,'FontName','Times New Roman');
set(gca,'LineWidth',1.5)
fig=gcf;
fig.PaperUnits = 'inches';
fig.PaperPosition = [0 0 5.5 4];
fig.PaperOrientation = 'landscape';
path = 'Results/distfitSize.pdf';
print(path, '-dpdf', '-r0');
system(strjoin({'pdfcrop' path path}, ' '));
