function fit_lfrOnRealData(dataName)
%DO ONLY RUN ONE INSTANCE AT A TIME! - This functions creates intermediate
%files with non-unique names. The 3rd party progam for LFR expects so.
origGraphPath = 'Data/';
numSamples = 100;

d = dataName;
disp(['--------' d '-------']);

disp('read the fitted models');
load([origGraphPath 'result_individualComm_'  d '_100_1000_sample500_v2.mat']);
nC = length(res);
commSizes = nan(nC,1);
for s = 1:nC
    commSizes(s) = length(res(s).members);
end
maxNodeIndex = sum(commSizes);
[~,commOrder] = sort(commSizes, 'ascend');
originalGraph = sparse(maxNodeIndex, maxNodeIndex);
originalCommunities = cell(nC,1);
lengthSoFar = 0;
for t = 1:nC
    c = commOrder(t);
    block = (lengthSoFar + 1) : (lengthSoFar + commSizes(c));
    originalCommunities{t} = degree_ord(res(c).comm);
    originalGraph(block,block) = originalCommunities{t};
    lengthSoFar = lengthSoFar + commSizes(c);
end

disp('prepare parameters');
mu = 0; % mixing parameter

degDist = sum(originalGraph);
N = length(originalGraph(degDist>=1));
Const = polyfit(log(1:N),log(sort(degDist(degDist>=1), 'descend')), 1);
m = Const(1);
gamma = Const(2); %power law exponent

Const = polyfit(log(1:nC)',log(sort(commSizes, 'descend')), 1);
m = Const(1);
beta = Const(2); %power law exponent
if isnan(beta)
    warning('fitting the dist of comm sizes failed');
    beta = 1;
end

% we need
%# number of nodes
%# average degree
%# maximum degree
%# exponent for the degree distribution 
%# exponent for the community size distribution
%# mixing parameter
%# minimum for the community sizes
%# maximum for the community sizes
parameterFile = 'parameters.dat';
paramOut = fopen(parameterFile, 'w');
fprintf(paramOut, '%d\n%f\n%f\n%f\n%f\n%f\n%d\n%d\n', ...
    N, full(mean(degDist)), full(max(degDist)), gamma, beta, mu, min(commSizes), max(commSizes));
fclose(paramOut);
disp('run LFR');
for s = 1:numSamples
    not_again = true;
    while not_again
        system('./benchmark_2_1/benchmark');

        M = importdata('network.dat');
        if iscell(M) % then it says inside: 'something went wrong'
            fprintf('retrying LFR');
        else
            not_again = false;
        end
    end
    newGraph = sparse(M(:,1), M(:,2), 1, N,N);% 1-based indexing

    disp('get community information');
    C = importdata('community.dat');
    disp('check quality as a hyperbolic model');
    comms = [];
    for i=1:max(C(:,2))
        comms(i).members=C(C(:,2)==i,1);     
        comms(i).paramType='H,gamma';
        comms(i).p1 = 0;
        comms(i).p2 = floor(length(comms(i).members)/2-1);
        comms(i).LL = -Inf;
        comms(i).model = [];
    end
    nC = length(comms); 
    commSizes = nan(nC,1);
    for i=1:nC
        [comms(i).comm, order] = degree_ord(newGraph(comms(i).members,comms(i).members));
        comms(i).members = comms(i).members(order);
        commSizes(i) = length(comms(i).members);
    end
    parfor i = 1:nC
        fprintf('.');
        [ comms(i).p1, comms(i).p2, comms(i).LL ] = recoverCommunity(comms(i).comm, comms(i).paramType);
        comms(i).model = makeCommunity(commSizes(i), comms(i).p1, comms(i).p2, getCondition(comms(i).paramType));
    end
    save(['Results/LFRresult_' d '_' num2str(s) '.mat'], 'comms');
end
end
