function comms = fit_sbmOnRealData(dataName)
origGraphPath = 'Data/';
sbmType = 'degree';

d = dataName;
disp(['--------' d '-------']);

disp('read the fitted models');
load([origGraphPath 'result_individualComm_'  d '_100_1000_sample500_v2.mat']);
nC = length(res);
commSizes = nan(nC,1);
for s = 1:nC
    commSizes(s) = length(res(s).members);
end
maxNodeIndex = sum(commSizes);
[~,commOrder] = sort(commSizes, 'ascend');
originalGraph = sparse(maxNodeIndex, maxNodeIndex);
originalCommunities = cell(nC,1);
lengthSoFar = 0;
for t = 1:nC
    c = commOrder(t);
    block = (lengthSoFar + 1) : (lengthSoFar + commSizes(c));
    originalCommunities{t} = degree_ord(res(c).comm);
    originalGraph(block,block) = originalCommunities{t};
    lengthSoFar = lengthSoFar + commSizes(c);
end

fn = ['Results/SBMinput_' d '.txt'];
fn2 = [fn(1:end-4) '_block-fit-result.txt'];
fn3 = [fn(1:end-4) '_block-gen-result.txt'];
fn4 = [fn(1:end-4) '_block-fit-result_2.txt'];

% fit SBM
disp('fit SBM');
if ~exist(fn2,'file')
    [x,y]= find(originalGraph > 0);
    edgeList = [x-1,y-1]; %zero-based!
    fid = fopen(fn, 'w');
    fprintf(fid, '%d %d\n',edgeList');
    fclose(fid);
    [~, blockFitResult] = system(['./blockmodel_ntamas/blockmodel/build/src/ui/block-fit/block-fit -g '...
        num2str(nC) ' --model ' sbmType ' - <' fn]);
    fid = fopen(fn2, 'w');
    fprintf(fid, '%s', blockFitResult);
    fclose(fid);
else
    disp('    already done.'); % no need to load, will be used from the file
end

% block-gen fails when too many communities should be created.
% -> we make a graph of only 100 communities
if ~strcmp(d, 'youtube')   
    nC = 100;
end
% generate graph
disp('generate graph');
if ~exist(fn3,'file')
    [~, blockGenResult] = system(['./blockmodel_ntamas/blockmodel/build/src/ui/block-gen/block-gen -c '...
        num2str(nC) ' --model ' sbmType ' ' fn2]);
    k = strfind(blockGenResult, char(10));
    k = k(1);
    blockGenResult = blockGenResult((k+1):end);  %drop first line
    fid = fopen(fn3, 'w');
    fprintf(fid, '%s', blockGenResult);
    fclose(fid);
else
    disp('    already done, load result.');
    blockGenResult = fileread(fn3);
end

disp('convert to graph.');
pieces = sscanf(blockGenResult,'%d%d');
edges = reshape(pieces,2, length(pieces)/2)';
edges = edges + 1;
newGraph = sparse(edges(:,1), edges(:,2), ones(length(edges),1), size(originalGraph,1), size(originalGraph,2));

% fit SBM
disp('fit SBM on generated graph');
if ~exist(fn4,'file')
    [~, blockFitResult] = system(['./blockmodel_ntamas/blockmodel/build/src/ui/block-fit/block-fit -g '...
        num2str(nC) ' --model ' sbmType ' ' fn3]);
    fid = fopen(fn4, 'w');
    fprintf(fid, '%s', blockFitResult);
    fclose(fid);
else
    disp('    already done, load result.');
    blockFitResult = fileread(fn4);
end

% hyperbolic communities of resulting blocks
disp('check quality as a hyperbolic model');
resPieces = strsplit(blockFitResult); 
startLine = find(not(cellfun('isempty', strfind(resPieces, 'TYPES'))));
groupAssignment = str2num(char(resPieces((1:length(originalGraph)) + startLine)))+1;
comms = [];
for i=1:nC
    % we assume that block-fit finds well what block-gen generated
    comms(i).members=find(groupAssignment==i);     
    comms(i).paramType='H,gamma';
    comms(i).p1 = 0;
    comms(i).p2 = floor(length(comms(i).members)/2-1);
    comms(i).LL = -Inf;
    comms(i).model = [];
end
commSizes = nan(nC,1);
for i=1:nC
    [comms(i).comm, order] = degree_ord(newGraph(comms(i).members,comms(i).members));
    comms(i).members = comms(i).members(order);
    commSizes(i) = length(comms(i).members);
end

parfor i = 1:nC
    fprintf('.');
    [ comms(i).p1, comms(i).p2, comms(i).LL ] = recoverCommunity(comms(i).comm, comms(i).paramType);
    comms(i).model = makeCommunity(commSizes(i), comms(i).p1, comms(i).p2, getCondition(comms(i).paramType));
end
save(['Results/DCSBMresult_' d '.mat'], 'comms', '-v7.3');
end